@@ -277,7 +277,7 @@ returns false if the request is a sub-request or internal redirect.
 Get or set the allowed methods bitmask. This allowed bitmask should be
 set whenever a 405 (method not allowed) or 501 (method not implemented)
 answer is returned. The bit corresponding to the method number should be
-et.
+set.
 
    unless ($r->method_number == M_GET) {
      $r->allowed($r->allowed | (1<<M_GET) | (1<<M_HEAD) | (1<<M_OPTIONS));
@@ -467,6 +467,12 @@ Lookup the remote user's system name.  Might return I<undef> if the
 remote system is not running an RFC 1413 server or if the configuration
 directive B<IdentityCheck> is not turned on.
 
+=item $r-E<gt>user( [$user] )
+
+If an authentication check was successful, the authentication handler
+caches the user name here. Sets the user name to the optional first
+argument.
+
 =back
 
 More information about the client can be obtained from the
@@ -554,14 +560,12 @@ always undefined.
 
 =item $c-E<gt>user( [$user] )
 
-If an authentication check was successful, the authentication handler
-caches the user name here. Sets the user name to the optional first
-argument.
+Deprecated, use C<$r-E<gt>user> instead.
 
 =item $c-E<gt>auth_type
 
-Returns the authentication scheme that successfully authenticate
-C<$c-E<gt>user>, if any.
+Returns the authentication scheme used to successfully authenticate
+C<$r-E<gt>user>, if any.
 
 =item $c-E<gt>aborted
 
@@ -656,7 +660,7 @@ Then during the authentication stage the server uses the current
 authentication realm, from C<$r-E<gt>auth_name>, to determine which set of
 credentials to authenticate.
 
-=item $r-E<gt>document_root ( [$docroot] )
+=item $r-E<gt>document_root( [$docroot] )
 
 When called with no argument, returns a reference to the current value
 of the per server configuration directive B<DocumentRoot>. To quote the
@@ -679,6 +683,33 @@ example dynamically sets the document root based on the request's
     
    PerlTransHandler trans_handler
 
+=item $r-E<gt>server_root_relative( [$relative_path] )
+
+If called without any arguments, this method returns the value of the
+currently-configured C<ServerRoot> directory.
+
+If a single argument is passed, it concatenates it with the value of
+C<ServerRoot>. For example here is how to get the path to the
+I<error_log> file under the server root:
+
+ my $error_log = $r->server_root_relative("logs/error_log");
+
+See also the next item.
+
+=item Apache-E<gt>server_root_relative( [$relative_path] )
+
+Same as the previous item, but this time it's used without a request
+object. This method is usually needed in a startup file. For example
+the following startup file modifies C<@INC> to add a local directory
+with perl modules located under the server root and after that loads a
+module from that directory.
+
+  BEGIN {
+      use Apache():
+      use lib Apache->server_root_relative("lib/my_project");
+  }
+  use MyProject::Config ();
+
 =item $r-E<gt>allow_options
 
 The C<$r-E<gt>allow_options> method can be used for
@@ -1004,6 +1035,11 @@ The result is "bar", not the "SCALAR(0xDEADBEEF)" you might have expected. If
 you really want the reference to be printed out, force it into a scalar
 context by using C<print(scalar($foo))>.
 
+The print-a-scalar-reference feature is now deprecated. There are
+known bugs when using it and it's not supported by mod_perl 2.0. If
+you have a scalar reference containing a string to be printed,
+dereference it before sending it to print.
+
 =item $r-E<gt>send_fd( $filehandle )
 
 Send the contents of a file to the client.  Can for instance be used
@@ -1182,7 +1218,13 @@ send to the error_log if B<LogLevel> is set to B<warn> or higher.
 
 =item Apache::unescape_url($string)
 
-Handy function for unescapes.  Use this one for filenames/paths.
+  $unescaped_url = Apache::unescape_url($string)
+
+Handy function for unescapes.  Use this one for
+filenames/paths. Notice that the original C<$string> is mangled in the
+process (because the string part of PV shrinks, but the variable is
+not updated, to speed things up).
+
 Use unescape_url_info for the result of submitted form data.
 
 =item Apache::unescape_url_info($string)
