@@ -121,6 +121,7 @@ perl_cccdlflags="`$perl_config 'cccdlflags'`"
 perl_ld="`$perl_config 'ld'`"
 perl_ldflags="`$perl_config 'ldflags'`"
 perl_lddlflags="`$perl_config 'lddlflags'`"
+perl_dlext="`$perl_config 'dlext'`"
 
 case "$os_version" in
     aix*)
@@ -131,6 +132,17 @@ case "$os_version" in
 	esac
     	perl_lddlflags="$perl_lddlflags $XLINKER-bI:\$(APACHELIBEXEC)/httpd.exp"
 	;;
+    
+    darwin*)
+    # OS X has .bundle's, .so's and .dylib's, but we need to normalize
+    # to .so, so keep it simple, and blindly normalize
+    perl_dlext="`echo $perl_dlext | sed -e's/bundle/so/' | sed -e's/dylib/so/'`"
+    ;;
+
+    cygwin*)
+	perl_ld="gcc -shared"
+	;;
+	
     * )    ;;
 esac
 
@@ -154,6 +166,18 @@ if ($ARGV[0] eq "DSO" and $^O eq "hpux" and $Config{ld} =~ /ld$/) {
     }
 }
 
+# add httpd.dll for cygwin
+if($ARGV[0] eq 'DSO' && $^O eq cygwin) {
+    chomp $ldopts;
+    $ldopts .= join (' ', '', 
+        '-Wl,--out-implib=libperl.dll.a',
+        '-Wl,--export-all-symbols',
+        '-Wl,--enable-auto-import',
+        '-Wl,--stack,8388608',
+        '-Wl,--enable-auto-image-base',
+        '-lhttpd');
+}
+
 print $ldopts;
 EOT
 perl_libs="`$perl_interp $tmpfile2 $build_type`"
@@ -227,6 +251,7 @@ echo "PERL_INC=$perl_inc"
 echo "PERL_LD=$perl_ld"
 echo "PERL_LDFLAGS=$perl_ldflags"
 echo "PERL_LDDLFLAGS=$perl_lddlflags"
+echo "PERL_DLEXT=$perl_dlext"
 echo "PERL_LIBS=$perl_libs $perl_static_ar"
 echo "PERL_XSINIT=$perl_xsinit"
 echo "PERL_XSUBPP=$perl_xsubpp"
