@@ -277,13 +277,8 @@ void perl_shutdown (server_rec *s, pool *p)
 
     mp_request_rec = 0;
 
-    av_undef(orig_inc);
-    SvREFCNT_dec((SV*)orig_inc);
-    orig_inc = Nullav;
-
-    av_undef(cleanup_av);
-    SvREFCNT_dec((SV*)cleanup_av);
-    cleanup_av = Nullav;
+    MP_safe_av_undef(orig_inc)
+    MP_safe_av_undef(cleanup_av)
 
 #ifdef PERL_STACKED_HANDLERS
     hv_undef(stacked_handlers);
@@ -294,7 +289,7 @@ void perl_shutdown (server_rec *s, pool *p)
     perl_destruct(perl);
     perl_free(perl);
 
-#ifdef USE_THREADS
+#ifdef PERL_SYS_TERM
     PERL_SYS_TERM();
 #endif
 
@@ -683,10 +678,8 @@ void perl_startup (server_rec *s, pool *p)
 	MP_TRACE_g(fprintf(stderr, "'%s' ", argv[i]));
     MP_TRACE_g(fprintf(stderr, "..."));
 
-#ifdef USE_THREADS
-# ifdef PERL_SYS_INIT
-    PERL_SYS_INIT(&argc,&argv);
-# endif
+#ifdef PERL_SYS_INIT
+    PERL_SYS_INIT(&argc,(char***)&argv);
 #endif
 
 #ifndef perl_init_i18nl10n
@@ -1159,9 +1152,7 @@ void mod_perl_end_cleanup(void *data)
     perl_clear_env();
 
     /* reset @INC */
-    av_undef(GvAV(incgv));
-    SvREFCNT_dec(GvAV(incgv));
-    GvAV(incgv) = Nullav;
+    MP_safe_av_undef(GvAV(incgv))
     GvAV(incgv) = av_copy_array(orig_inc);
 
     /* reset $/ */
