@@ -1,15 +1,17 @@
-#! /usr/local/bin/perl
+#!perl
 
 unless (defined $ENV{MOD_PERL}) {
     die "\$ENV{MOD_PERL} not set!";
 }
 
 BEGIN {
-    #./blib/lib:./blib/arch
-    use ExtUtils::testlib;
-
     use lib map { "$Apache::Server::CWD/$_" } qw(t/docs blib/lib blib/arch);
     require "blib.pl" if -e "./t/docs/blib.pl";
+    #Perl ignores w/ -T
+    if ($ENV{PERL5LIB} and $ENV{PASS_PERL5LIB}) {
+         unshift @INC, map { Apache->untaint($_) } split ":", $ENV{PERL5LIB};
+    }
+
     $Apache::Server::Starting or warn "Server is not starting !?\n";
     \$Apache::Server::Starting == \$Apache::ServerStarting or 
 	warn "GV alias broken\n";
@@ -17,24 +19,28 @@ BEGIN {
 	warn "GV alias broken\n";
 }
 
-if (-e "t/docs/local.pl") {
+if ($] >= 5.005 and -e "t/docs/local.pl") {
     eval {
 	require "local.pl"; 
     }; $@='' if $@;
 }
 
+use Socket (); #test DynaLoader vs. XSLoader workaroud
+use Apache ();
+use Apache::Registry ();
+unless ($INC{'Apache.pm'} =~ /blib/) {
+    die "Wrong Apache.pm loaded: $INC{'Apache.pm'}";
+}
+
+my $version = defined $^V ? sprintf("v%vd", $^V) : $];
+Apache::add_version_component("Perl/$version");
+
 # BSD/OS 3.1 gets confused with some dynamically loaded code inside evals,
 # so make sure IO::File is loaded here, rather than later within an eval.
 # this should not harm any other platforms, since IO::File will be used
 # by them anyhow.
 use IO::File ();
 
-use Apache ();
-use Apache::Registry ();
-unless ($INC{'Apache.pm'} =~ /blib/) {
-    die "Wrong Apache.pm loaded: $INC{'Apache.pm'}";
-}
-
 Apache::Constants->export(qw(HTTP_MULTIPLE_CHOICES));
 
 eval {
@@ -61,7 +67,7 @@ eval {
 
 $Apache::DoInternalRedirect = 1;
 $Apache::ERRSV_CAN_BE_HTTP  = 1;
-$Apache::Server::AddPerlVersion = 1;
+#$Apache::Server::AddPerlVersion = 1;
 #warn "ServerStarting=$Apache::ServerStarting\n";
 #warn "ServerReStarting=$Apache::ServerReStarting\n";
 
@@ -100,7 +106,10 @@ sub main::access { print ++$Access::Cnt }
 
 $ENV{GATEWAY_INTERFACE} =~ /^CGI-Perl/ or die "GATEWAY_INTERFACE not set!";
 
-sub Outside::imported {4}
+sub Outside::code {4}
+%Outside::hash = (one => 1);
+@Outside::array = qw(one);
+$Outside::scalar = 'one';
 
 #will be redef'd during tests
 sub PerlTransHandler::handler {-1}
@@ -165,7 +174,7 @@ sub Apache::AuthenTest::handler {
     my($res, $sent_pwd) = $r->get_basic_auth_pw;
     return $res if $res; #decline if not Basic
 
-    my $user = lc $r->connection->user;
+    my $user = lc $r->user;
     $r->notes("DoAuthenTest", 1);
     
     unless($user eq "dougm" and $sent_pwd eq "mod_perl") {
@@ -190,7 +199,7 @@ sub My::DirIndex::handler {
     print "1..$x\n";
     my $i = 1;
     for my $e (@entries) {
-	print "ok $i ($e)\n";
+	print "ok $i #($e)\n";
 	++$i;
     }
     1;
