@@ -1,5 +1,5 @@
-
-use Apache::test;
+#!perl
+use Apache::testold;
 
 my $r = shift;
 $r->send_http_header('text/plain');
